{{ title }} {{summary && summary.status.same}} Same {{summary && summary.status.different}} Different {{summary && summary.status.failure}} Failure
{{ summary && summary.time.end.replace('T', ' ').slice(0, 19) }}

    {{JSON.stringify(currentTrial, undefined, 4)}}

    {{JSON.stringify(addOns, undefined, 4)}}

{{ currentIndex + 1 }} / {{ filteredTrials.length }} {{ currentTrial.name }} ({{ currentTrial.path }})